==> haskell-listlike-4.5.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-listlike.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ListLike
version: 4.5.1
id: ListLike-4.5.1-7vYa0SJalRl4vvIZNQ905Q
key: ListLike-4.5.1-7vYa0SJalRl4vvIZNQ905Q
license: BSD3
copyright: Copyright (c) 2007-2008 John Goerzen
maintainer: John Lato <jwlato@gmail.com>
stability: Stable
homepage: http://github.com/JohnLato/listlike
synopsis: Generic support for list-like structures
description:
    Generic support for list-like structures in Haskell.
    .
    The ListLike module provides a common interface to the various Haskell
    types that are list-like.  Predefined interfaces include standard
    Haskell lists, Arrays, ByteStrings, and lazy ByteStrings.  Custom
    types can easily be made ListLike instances as well.
    .
    ListLike also provides for String-like types, such as String and
    ByteString, for types that support input and output, and for types that can handle
    infinite lists.
category: Generics
author: John Goerzen
exposed: True
exposed-modules:
    Data.ListLike Data.ListLike.Base Data.ListLike.Chars
    Data.ListLike.CharString Data.ListLike.FoldableLL Data.ListLike.IO
    Data.ListLike.Instances Data.ListLike.String Data.ListLike.Text
    Data.ListLike.Text.Builder Data.ListLike.Text.Text
    Data.ListLike.Text.TextLazy Data.ListLike.UTF8 Data.ListLike.Utils
    Data.ListLike.Vector Data.ListLike.Vector.Generic
    Data.ListLike.Vector.Storable Data.ListLike.Vector.Unboxed
    Data.ListLike.Vector.Vector Data.ListLike.DList
    Data.ListLike.FMList
abi: 575cbd0171a876256b9554a6a2d32288
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/ListLike-4.5.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/ListLike-4.5.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/ListLike-4.5.1
hs-libraries: HSListLike-4.5.1-7vYa0SJalRl4vvIZNQ905Q
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    deepseq-1.4.2.0 dlist-0.8.0.2-6Wnps4GD7EFnRucVzXIFD
    fmlist-0.9-5oU3ipIc7YtDbR5OmEYvtd
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-listlike/html/ListLike.haddock
haddock-html: /usr/share/doc/haskell-listlike/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-listlike-4.5.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-listlike.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ListLike
version: 4.5.1
id: ListLike-4.5.1-DxjrkLDe3UGIfyKkKXLWMF
key: ListLike-4.5.1-DxjrkLDe3UGIfyKkKXLWMF
license: BSD3
copyright: Copyright (c) 2007-2008 John Goerzen
maintainer: John Lato <jwlato@gmail.com>
stability: Stable
homepage: http://github.com/JohnLato/listlike
synopsis: Generic support for list-like structures
description:
    Generic support for list-like structures in Haskell.
    .
    The ListLike module provides a common interface to the various Haskell
    types that are list-like.  Predefined interfaces include standard
    Haskell lists, Arrays, ByteStrings, and lazy ByteStrings.  Custom
    types can easily be made ListLike instances as well.
    .
    ListLike also provides for String-like types, such as String and
    ByteString, for types that support input and output, and for types that can handle
    infinite lists.
category: Generics
author: John Goerzen
exposed: True
exposed-modules:
    Data.ListLike Data.ListLike.Base Data.ListLike.Chars
    Data.ListLike.CharString Data.ListLike.FoldableLL Data.ListLike.IO
    Data.ListLike.Instances Data.ListLike.String Data.ListLike.Text
    Data.ListLike.Text.Builder Data.ListLike.Text.Text
    Data.ListLike.Text.TextLazy Data.ListLike.UTF8 Data.ListLike.Utils
    Data.ListLike.Vector Data.ListLike.Vector.Generic
    Data.ListLike.Vector.Storable Data.ListLike.Vector.Unboxed
    Data.ListLike.Vector.Vector Data.ListLike.DList
    Data.ListLike.FMList
abi: d6fbdf90c8faaf208d59f19f5589505b
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/ListLike-4.5.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/ListLike-4.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/ListLike-4.5.1
hs-libraries: HSListLike-4.5.1-DxjrkLDe3UGIfyKkKXLWMF
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    deepseq-1.4.2.0 dlist-0.8.0.3-BHFBNaw8k6n9WiaUNzoXpk
    fmlist-0.9-5oU3ipIc7YtDbR5OmEYvtd
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-listlike/html/ListLike.haddock
haddock-html: /usr/share/doc/haskell-listlike/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
